# -*- encoding: utf-8 -*-
'''
@File    :   __init__.py
@Time    :   2019/08/05 10:39:27
@Author  :   hao qihan 
@Version :   1.0
@Contact :   2263310007@qq.com
'''
from haoutils.excel import *  # excel相关的模块
from haoutils.haotime import * # 时间相关的模块
from haoutils.ssh import *   # 连接服务器相关的模块


__version__ = "0.2"
__author__ = "haoqihan"





# -*- encoding: utf-8 -*-
'''
@File    :   excel.py
@Time    :   2019/08/05 12:38:21
@Author  :   hao qihan 
@Version :   0.1
@Contact :   2263310007@qq.com
'''
import os
from openpyxl import Workbook
from openpyxl import load_workbook
from openpyxl.styles import Font, Alignment, PatternFill, Border, Side


class Excel(object):


    # 设置字体大小和样式
    def font(self, name="微软雅黑", size=14, bold=False, color="000000"):
        return Font(name=name, size=size, bold=bold, color=color)

    # 设置背景颜色
    def fill(self, fgColor="DDDDDD"):
        return PatternFill("solid", fgColor=fgColor)

    # 设置对其格式
    def alignment(self, format="center"):
        return Alignment(horizontal=format, vertical=format)

    # 设置边框线
    def border(self, style="thin", color="000000"):
        side = Side(style=style, color=color)
        return Border(left=side, right=side, top=side, bottom=side)

    # 添加workbook
    def create_workbook(self,filename):
        isE = os.path.exists(self.path)
        if isE:
            self.workbook = load_workbook(filename)
        else:
            self.workbook = Workbook()
            self.flag = 1
    # 添加sheet
    def create_sheet(self,sheetname):
        sheet = self.workbook.create_sheet(sheetname)
        return sheet

    # 设置样式
    def default_style(self, cell_obj):
        cell_obj.fill = self.fill()
        cell_obj.font = self.font()
        cell_obj.alignment = self.alignment()
        cell_obj.border = self.border()

    # 向excel表添加内容
    def create_demo(self, sheet):
        for i in "ABCDEFG":
            sheet.column_dimensions[i].width = 20
        row = ["运营商", "ismi", "手机型号", "mcc", "mnc", "采集日期"]
        for index, i in enumerate(row):
            xx = sheet.cell(1,index+1,index)
            self.set_style(xx)
        self.workbook.save(self.path)






# -*- encoding: utf-8 -*-
'''
@File    :   haotime.py
@Time    :   2019/08/05 11:18:42
@Author  :   hao qihan 
@Version :   0.1
@Contact :   2263310007@qq.com
'''
import time


def standard_time_to_time(strtime: str) -> float:
    """ 
    标准时间字符串转为时间戳
    :strtime 固定格式的字符串  Mon May  6 15:43:48 2019
    :return :返回 一个时间戳
    """
    timeint = time.strptime(strtime, "%a %b %d %H:%M:%S %Y")
    return time.mktime(timeint)


def ordinary_time_to_time(strtime: str) -> float:
    """
    yyyy-MM-dd格式的字符串转换为时间戳
    :strtime 固定格式的字符串 2019-08-05 11:18:42
    :return :返回 一个时间戳
    """
    timeint = time.strptime(strtime, "%Y-%m-%d %H:%M:%S")
    return time.mktime(timeint)


def time_to_ordinary_time(inttime: float) -> str:
    """
    时间戳转字符串 
    :floattime 时间戳 1564975122
    :return 时间字符串 2019-08-05 11:18:42
    """
    timeArray = time.localtime(inttime)
    strtime = time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
    return strtime


def time_to_standard_time(inttime: float) -> str:
    """
    时间戳转字符串 
    :floattime 时间戳 1564975122
    :return 时间字符串 
    """
    timeArray = time.localtime(inttime)
    strtime = time.strftime("%a %b %d %H:%M:%S %Y", timeArray)
    return strtime


if __name__ == "__main__":
    time_to_standard_time(1564975122.0)



# -*- encoding: utf-8 -*-
'''
@File    :   ssh.py
@Time    :   2019/08/05 11:05:23
@Author  :   hao qihan 
@Version :   0.1
@Contact :   2263310007@qq.com
'''
import time
import paramiko



class SSH:
    """
        定义连接服务器的类
    """

    def __init__(self, host, port, username, password):
        self.host = host
        self.port = port
        self.username = username
        self.password = password
        tran = paramiko.Transport(sock=(self.host, self.port))
        tran.connect(username=self.username, password=self.password)
        self.tran = tran

    def client_linux(self):
        """
        连接linux
        """
        self._client = paramiko.SSHClient()
        self._client._transport = self.tran

    def client_other(self):
        """
        连接其他的(例如：接口机、DPI等)
        """
        self.channel = self.tran.open_session()
        # 获取终端
        self.channel.get_pty()
        # 激活器
        self.channel.invoke_shell()

    def send_command(self, cmd):
        """
        只能发送shell命令
        :cmd 命令
        """
        stdin, stdout, stderr = self._client.exec_command(cmd)
        res = stdout.read().decode('utf-8')
        return res

    def send_string(self, cmd):
        """
        可以发送任何命令，如：DPI或接口机命令都可以
        :cmd 命令
        """
        self.channel.send(cmd + "\r")
        res = ''
        while True:
            time.sleep(0.2)
            response = self.channel.recv(1024).decode('utf8')
            res += response
            if res.strip().endswith("#") or res.strip().endswith("$"):
                break
            if res.strip().endswith("(yes/no)?"):
                self.channel.send("yes")
        print("结束")
        return res

    def close(self):
        """
        关闭链接
        """
        self.tran.close()



from setuptools import setup, find_packages
from haoutils import __version__, __author__


with open("README.md", encoding="utf-8") as f:
    long_text = f.read()


setup(
    name="haoutils",
    version=__version__,
    long_description=long_text,
    long_description_content_type="text/markdown",
    url="https://github.com/haoqihan/haoutils",
    author=__author__,
    author_email="2263310007@qq.com",
    license='MIT Licence',
    packages=find_packages(),
    platforms=["window10", "Linux"],
    package_data={'': ['*']},
    install_requires=['paramiko',"openpyxl"],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    zip_safe=False
)
